package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````7"8``#0````XT0```````#0`(``+
M`"@`&P`:``8````T````-````#0```!@`0``8`$```0````$`````P```)0!
M``"4`0``E`$``!,````3````!`````$````!````````````````````_!$`
M`/P1```$`````!````$`````(````"`````@```84```&%````4`````$```
M`0````"`````@````(```'1-``!T30``!``````0```!````J,T``*C=``"H
MW0``:`(``*P2```&`````!````(```"PS0``L-T``+#=```@`0``(`$```8`
M```$````!````*@!``"H`0``J`$``$0```!$````!`````0```!0Y71D/+\`
M`#R_```\OP``]````/0````$````!````%'E=&0`````````````````````
M``````8````0````4N5T9*C-``"HW0``J-T``%@"``!8`@``!`````$````O
M;&EB+VQD+6QI;G5X+G-O+C(```0````0`````0```$=.50```````P````(`
M````````!````!0````#````1TY5`&$(0@"Z.Z+9R1QD+,J'X"TNH)_*$0``
M`$L````(````"``````0$`0E0`2`*`$``:"&`("``0``"R@$"3B@$D6*!`@(
M`````$L```!/````4P```%0```!:````6P```%P```!>````7P````````!A
M````8P```&0```!E``````````````#JT^\.;L7?'\[>1RUK?YI\+L6;MM1D
MU'P@_^0.N8WQ#MEQ6!SB1\8!L@&+;ZQ+X\#"Y3\LNN.2?/NA;&!K"4/69Z_,
M9D)%U>R)!W#3#13BGC)BV^W;S>.>##J7"UGH[>Q_J9R;X:<""J/@^TD`````
M````````````````&`(`````````````$@```(P"`````````````!(```!W
M`@`````````````2````#`$`````````````$@```),``````````````!(`
M```!`0`````````````1````R@(`````````````$@```),!````````````
M`!(```"U`@`````````````2````(@$`````````````$@```!$`````````
M`````"````!]`@`````````````2````ZP(`````````````$@```!D#````
M`````````!(```!(`@`````````````2````]P$`````````````$@```%,!
M`````````````!(```"T```````````````2````0P$`````````````$@``
M`#4!`````````````!(```!=`P`````````````2````#`,`````````````
M$@````0"`````````````!(```#_`0`````````````2````(```````````
M````(````+$!`````````````!(````1`0`````````````2````V`(`````
M````````$@```$\#`````````````!(````\```````````````@````XP(`
M````````````$@```%8``````````````!(```"#`0`````````````2````
M<P``````````````$@```/```````````````!(```"$```````````````2
M````(`,`````````````$@```/4"`````````````!$```##`@``````````
M```2````H0(`````````````$@```'`"`````````````!(````E!```````
M```````2````U```````````````$@```/P"`````````````!(```!Q`P``
M```````````1````=0$`````````````$@```&<"`````````````!(````I
M`@`````````````2````9P$`````````````$@```*@"`````````````!(`
M``"J`0`````````````2````%@$`````````````$@```'D#````````````
M`!(```"O`@`````````````2````<`,`````````````(0```)H"````````
M`````!(````#`P`````````````2````1P,`````````````$@```)\`````
M`````````!(```">`0`````````````2````.0,`````````````$@```&\#
M`````````````!$```"%`@`````````````2````7P(`````````````$@``
M`/`!`````````````!(```#C```````````````1````O`$`````````````
M$0```%P!`````````````!(```!D```````````````2````DP(`````````
M````$@```%8#`````````````!(````J`P`````````````B````6@(`````
M````````$@```,(``````````````!(```#``P``!'`````````2``\`+@0`
M`-!N``!V````$@`.`'`$``#P7@``5PP``!(`#@!J`P``$"0``$P"```2``X`
MF`,``&!8```%````$@`.`,T#``!0:P``?@,``!(`#@"6!```<%@```4"```2
M``X`200````@````````$@`+`%\$```0X````````!``&`"I`P``@%H``"D`
M```2``X`XP,``&!=``!V````$@`.`#D"```$@```!````!$`$`!'!````%<`
M`#L````2``X`:P0``%3P````````$``8`(0$```@7@``Q@```!(`#@`Z!```
M`.`````````0`!<`!P0``+!:``#8````$@`.`'T$```0X````````!``%P"C
M!```#.````0````1`!<`M@,``.!O```"````$@`.`$`$``!<)@```````!(`
M#@!/!```@&\``%T````2``X`/`0```#@````````(``7`,8#````@```!```
M`!$`$``3!```X%T``#<````2``X`\0,``*!7``"V````$@`.`*T$``"06P``
MT`$``!(`#@``;&EB<&5R;"YS;RXU+C(X`%]?9VUO;E]S=&%R=%]?`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A
M8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?
M;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?
M<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H
M<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C
M:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L
M7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,
M;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO
M8P!03%]M96UO<GE?=W)A<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR
M96%D+G-O+C``;W!E;C8T`&QS965K-C0`<F5A9`!P=&AR96%D7V=E='-P96-I
M9FEC`%]?97)R;F]?;&]C871I;VX`8VQO<V4`;&EB8RYS;RXV`%])3U]S=&1I
M;E]U<V5D`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!C;&]S961I
M<@!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S
M=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E
M861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`
M86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]S
M=&%C:U]C:&M?9F%I;`!L:6)C<GEP="YS;RXQ`'!A<E]C=7)R96YT7V5X96,`
M<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!?9G!?:'<`6%-?26YT97)N
M86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!X<U]I;FET`%]?;&EB8U]C<W5?:6YI
M=`!?7V)S<U]S=&%R=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI=%]E
M;G8`1TQ)0D-?,BXQ+C,`1TQ)0D-?,BXT`$=,24)#7S(N,RXR`$=,24)#7S(N
M,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C`````"``,``P`````````$````!```
M`````P`%``,`!@`'`````````````P`$``(``@```````P`%``,````#````
M```````````%``,``P`#``,``P````,``P````,``@````,``P````@``P`#
M``,``P`#```````$``,``P`#``<````````````#``,`"0`#`````0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`&`"\"```0````<````',?:0D```D`N@0``!`````4:6D-```(`,8$
M```0````<AEI"0``!@#0!```$````!)I:0T```4`W`0``!````!T&6D)```$
M`.8$```0````$&EI#0```P#R!`````````$``@#@`0``$``````````2:6D-
M```'`-P$```0````$&EI#0```@#R!````````*C=```(````K-T```@```#\
MWP``"`````3@```(````#.````@```#,WP``!@8``-#?```&"@``U-\```8+
M``#8WP``!AD``-S?```&'@``X-\```8A``#DWP``!B(``.C?```&)@``[-\`
M``8M``#PWP``!D(``/3?```&0P``^-\```9(``#<W@``!P$``.#>```'`@``
MY-X```<#``#HW@``!P0``.S>```'!0``\-X```<'``#TW@``!P@``/C>```'
M"0``_-X```<,````WP``!PT```3?```'#@``"-\```</```,WP``!Q```!#?
M```'$0``%-\```<2```8WP``!Q,``!S?```'%```(-\```<5```DWP``!Q8`
M`"C?```'%P``+-\```<8```PWP``!QH``#3?```'&P``.-\```<<```\WP``
M!QT``$#?```''P``1-\```<@``!(WP``!R,``$S?```')```4-\```<E``!4
MWP``!R<``%C?```'*```7-\```<I``!@WP``!RH``&3?```'*P``:-\```<L
M``!LWP``!RX``'#?```'+P``=-\```<P``!XWP``!S$``'S?```',@``@-\`
M``<S``"$WP``!S0``(C?```'-0``C-\```<V``"0WP``!S@``)3?```'.0``
MF-\```<Z``"<WP``!SL``*#?```'/```I-\```<]``"HWP``!S\``*S?```'
M0```L-\```=!``"TWP``!T0``+C?```'10``O-\```=&``#`WP``!T<``,3?
M```'20``R-\```=*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z)<&``"!P\>^``"+@P0!``"%P'0%Z.(#``"#Q`A;PP``````````
M``````#_LP0```#_HP@`````````_Z,,````:`````#IX/____^C$````&@(
M````Z=#_____HQ0```!H$````.G`_____Z,8````:!@```#IL/____^C'```
M`&@@````Z:#_____HR````!H*````.F0_____Z,D````:#````#I@/____^C
M*````&@X````Z7#_____HRP```!H0````.E@_____Z,P````:$@```#I4/__
M__^C-````&A0````Z4#_____HS@```!H6````.DP_____Z,\````:&````#I
M(/____^C0````&AH````Z1#_____HT0```!H<````.D`_____Z-(````:'@`
M``#I\/[___^C3````&B`````Z>#^____HU````!HB````.G0_O___Z-4````
M:)````#IP/[___^C6````&B8````Z;#^____HUP```!HH````.F@_O___Z-@
M````:*@```#ID/[___^C9````&BP````Z8#^____HV@```!HN````.EP_O__
M_Z-L````:,````#I8/[___^C<````&C(````Z5#^____HW0```!HT````.E`
M_O___Z-X````:-@```#I,/[___^C?````&C@````Z2#^____HX````!HZ```
M`.D0_O___Z.$````:/````#I`/[___^CB````&CX````Z?#]____HXP```!H
M``$``.G@_?___Z.0````:`@!``#IT/W___^CE````&@0`0``Z<#]____HY@`
M``!H&`$``.FP_?___Z.<````:"`!``#IH/W___^CH````&@H`0``Z9#]____
MHZ0```!H,`$``.F`_?___Z.H````:#@!``#I</W___^CK````&A``0``Z6#]
M____H[````!H2`$``.E0_?___Z.T````:%`!``#I0/W___^CN````&A8`0``
MZ3#]____H[P```!H8`$``.D@_?___Z/`````:&@!``#I$/W___^CQ````&AP
M`0``Z0#]____H\@```!H>`$``.GP_/___Z/,````:(`!``#IX/S___^CT```
M`&B(`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````:)@!``#IL/S___^C
MW````&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z/D````:+`!``#I@/S_
M__^CZ````&BX`0``Z7#\____H^P```!HP`$``.E@_/___Z/P````:,@!``#I
M4/S___^C]````&C0`0``Z4#\____H_@```!HV`$``.DP_/___Z,$`0``9I#_
MHR@!``!FD(U,)`2#Y/#_<?Q5B>57B<]64^AY`@``@<.IN@``48/L+(M!!(E%
MU(M!"(E%T&6A%````(E%Y#'`C4704(U%U%!1Z%K___^+@P`!``"#Q`Q04/^S
M%`$``.CD2@``BX,@`0``@\00@#@`#X0R`0``B[/\````@^P,_S;HXOS__X"(
MM@(```):_S;HT_S__X/$$("(M@(```&+!X/`!3W___\_#X>"`0``@^P,P>`"
M4.B-_O__BW74BP^#Q!")@W01``"+%HE-S,>#>!$```0```")$(V3"*/__XE0
M!(N3/`$``(E0"(V3"Z/__XE0#(/Y`7X=BWW,C58$C4@0C32^9I"+.H/"!(/!
M!(EY_#G6=?&+?<R#[`S'1+@,`````(/'`VH`4(V#<'C__U=0_[.`$0``Z%K[
M__^#Q"")QH7`#X26````@^P,_[.`$0``C7W@Z$S]__^)^HV#V*'__^C?*@``
M@\00A<`/A(4```"#[`S_LX`1``#HYOK__^A1_/__@\00B?"+3>1E,PT4````
M#X6S````C67P65M>7UV-8?S#Z-O[__^)@X`1``"%P`^$B@```(/L#%#H-/S_
M_XNS_````%G_-NB6^___@\00QH!A!@```.F;_O__@^P,_[.`$0``Z!G[__^#
MQ!")QNE2____BX-\$0``A<!T$8/L#%#HO$@``(/$$.E@____B?J-@XVA___H
M)RH``(F#?!$``(7`#X1%____Z])04(V#BJ'___^S)`$``%#H\_S__X/L#&H!
MZ(G]___HE$D``#'M7HGA@^3P4%12Z"(```"!PV2X``"-@Q"1__]0C8.PD/__
M4%%6_[,L`0``Z,/Z___TBQPDPV:09I!FD&:09I!FD&:0BQPDPV:09I!FD&:0
M9I!FD.C@````@<(;N```C8I``0``C8)``0``.<AT'8N""`$``(7`=!-5B>6#
M[!11_]"#Q!#)PXUT)@"0PXVT)@````#HH````('"V[<``%6)Y5.-BD`!``"-
M@D`!``"#[`0IR,'X`HG#P>L?`=C1^'04BY(,`0``A=)T"H/L"%!1_]*#Q!"+
M7?S)PXVT)@````!FD%6)Y5/H5____X'#A[<``(/L!("[4`$```!U)XN#*`$`
M`(7`=!&#[`S_LS0!``#HE?S__X/$$.@U____QH-0`0```8M=_,G#C;0F````
M`&:0Z5O___^+%"3#9I!FD&:0D%6-4#A75E.![`P#``")1"1HC40D>(VL)(``
M``!EBQT4````B9PD_`(``#';B40D"(V<)``!``")1"00B70D&(E\)!R)WXUV
M`(M*!(L"QT7\`````(/%$,=%]`````"#P@@/R(E%Z(G(P>@(B0PD)0#_``#'
M1"0$`````(G#B<C!Z!@)V(L<)(G9P>,(P>$8"<B)V8'A``#_``G!B4WP.>]U
MIHM4)`B+1"00@<(``@``B<6)%"2-=@"+56B+16R#Q0C'17P`````,U4X,T4\
M,U4(,T4,,U7X,T7\B<>)T8G0`=$/K/@?"<&)37@[+"1UR(ML)&B+=12+10"+
M30B+?1R+502+70R)="0$BW48B4PD&(G!B7PD#(M](`^LT1N)="0(B<:)7"0<
MP>8%BUT0BVTD"<Z)?"10B50D%(M\)%`QT@-\)'B);"14B?F+;"14$VPD?(D<
M)('!F7F"6HE$)!")ZXGP@],``<B+3"08$=J+'"2)1"0@B50D)(M4)`B)W3'5
MB>\ASXGZBWPD"(M$)"#'1"0D`````(ML)!R+3"0,QT0D/``````Q^HM\)!C'
M1"1$``````'0B?J)_HE$)""+!"3!XAX/K.X"B=.+5"0("?,#E"2`````$XPD
MA````(E<)#B+="0XB5PD,(G+B=&+5"04@<&9>8):@],`,<:+1"00B4PD*(GW
MBW0D((M,)"B)7"0L(<?'1"0L`````(G[BSPDB?`Q^XM\)"0!V<'@!8E$)"B)
M_8GWBW0D*`^L[QL)_HGPBW0D!`'(B40D*(M$)!")P0^LT`+!X1Z)RPG#B=V)
M7"1`BQPD`YPDB````(M,)##'1"1,`````!.T)(P```")V(M\)"0%F7F"6HGR
MBW0D((/2`#'I,=LASC-T)#B)\0'!BT0D*!'3BU0D+(E,)#")QHE<)#2+7"0\
M#ZS0&\'F!<=$)#0`````B<$)\8MT)"")R`-$)#")\@^L_@*)1"0PBWPD,,'B
M'HGQB=8)SHM,)#@#C"20````B<@3G"24````B70D2`69>8):B=J#T@`Q]2-L
M)"@S;"1`B>DQVXML)#0!P8GX$=/!X`6)3"0@#ZSO&XE<)"2)PPG[B=@#1"0@
MB40D(,=$)"0`````BTPD*(M<)"S'1"0\`````(G(P>`>#ZS9`HM<)$3'1"1$
M`````(G""<J+3"1``XPDF````(G($YPDG````(G5B50D.`69>8):B=J)\8MT
M)$B#T@`QZ2-,)#")1"0HB50D+(M$)"")RC';,?*)T0-,)"@37"0LP>`%B4PD
M*(M4)"2)P8M$)"")7"0LBUPD-,=$)"P`````#ZS0&XE$)$`+3"1`B<B+3"0P
M`T0D*(E$)"B)R`^LV0+!X!Z)P@G*B50D0`.T)*````")\(MT)#B)5"18!9EY
M@EHQU2-L)""+5"0L,>Z+7"0DQT0D-`````")\<=$)$P``````<&+1"0HB<:)
MQ\'F!0^LUQN)="0PBW0D,`G^B?`!R(M,)"")1"0PB<[!YAZ)\(G.#ZS>`HM<
M)#R)\8G&"<Z+3"0X`XPDJ````(G($YPDK````(M,)%B)]069>8):B=J)="1(
M@](`,?&+="0H,=LASC-T)$")\0'!BT0D,!'3BU0D-(E,)"")QHE<)"2+3"0H
M#ZS0&\'F!<=$)"0`````B<,)\XG8`T0D((M<)"R)1"0@B<C!X!X/K-D"B<8)
MSHET)#B+3"1``XPDL````(M4)"2)="18B<B+7"0TQT0D+``````%F7F"6C'U
MBW0D2"-L)##'1"0\`````#'UQT0D1`````")Z0'!BT0D(,'@!8E$)"B+1"0@
MBVPD*`^LT!N)1"1`"VPD0(GH`<B+3"0PB40D*(G(#ZS9`L'@'HG""<H#M"2X
M````BTPD6(GPBW0D.(G5B50D0`69>8):,=$C3"0@BU0D+#'.B?$!P8M$)"B)
MQL'F!8ET)#")Q@^LUAN)="1(BW0D,`MT)$B)\`'(B40D,,=$)#0`````BUPD
M((MT)"2+?"0PQT0D)`````")VHG9BUPD+,=$)$P`````#ZSQ`L'B'L=$)#P`
M````"<J+3"0X`XPDP````(G(B50D2`69>8):,=4C;"0H,VPD0(GIBVPD-(E4
M)%@!P8GXP>`%#ZSO&XE$)""+="0@"?Z)\(MT)$@!R(M,)"B)1"0@B<@/K-D"
MP>`>B<()RHM,)$`#C"3(````B<B+3"18B=6)5"0X!9EY@EHQT2-,)#"+5"0D
M,<Z)\0'!BT0D(,'@!8G&BT0D(`^LT!N)1"0H"W0D*(GP`<B)1"0HQT0D+```
M``"+3"0PBUPD-(MT)#C'1"0T`````(G(QT0D1`````#!X!X/K-D"BUPD/,=$
M)$P`````B<()RHM,)$@#C"30````B<B)5"1`!9EY@EHQU2-L)"")5"18,>Z+
M5"0LBVPD)(GQ`<&+1"0HB<^)P<'A!8E,)#")T8MT)#")P@^LRAL)UHGP`?B+
M?"0@B40D,(GYB?[!X1X/K.X"B<B)\8G&"<Z+3"0X`XPDV````(G($YPDW```
M`(M,)%B)]069>8):B=J)="1(@](`,?&+="0H,=LASC-T)$")\0'!BT0D,!'3
MBU0D-(E,)"")QHE<)"0/K-`;P>8%B<,)\XG8`T0D((M,)"C'1"0D`````(M<
M)"R+5"0DB40D((G(QT0D/`````#!X!X/K-D"BUPD-,=$)"P`````B<;'1"1$
M``````G.BTPD0`.,).````")R(ET)#@%F7F"6HET)%@Q]8MT)$@C;"0P,?6)
MZ0'!BT0D(,'@!8E$)"B+1"0@BVPD*`^LT!N)1"1`"VPD0(GH`<B+3"0PB40D
M*(G(#ZS9`L'@'HG""<H#M"3H````BTPD6(GPBW0D.(E4)$")U069>8):,=$C
M3"0@,<Z)\0'!BT0D*(M4)"S'1"0T`````(M<)"#'1"1,`````(G&QT0D/```
M``#!Y@6)="0PB<8/K-8;B=J)="1(BW0D,`MT)$B)\(MT)"3'1"0D``````'(
MB=G!XAZ+7"0L#ZSQ`HE$)#"+?"0P"<J+3"0X`XPD\````(G(B50D6`69>8):
M,=4C;"0H,VPD0(GIBVPD-(E4)$@!P8GXP>`%#ZSO&XE$)""+="0@"?Z)\`'(
MBTPD*(E$)"")R`^LV0+!X!Z)P@G*BTPD0`.,)/@```")R(M,)%B)5"0XB=4%
MF7F"6C'1(TPD,(MT)$C'1"0L`````(M4)"2+7"0TQT0D1``````QSL=$)#0`
M````B?''1"1,``````'!BT0D(,'@!8G&BT0D(`^LT!N)1"0H"W0D*(GPBW0D
M.`'(BTPD,(E$)"B)R`^LV0*+7"0\P>`>B<()RHM,)$@#C"0``0``B<B)5"1`
M!9EY@EHQU2-L)"")5"18,>Z+5"0LBVPD)(GQ`<&+1"0HB<^)P<'A!8E,)#")
MT8MT)#")P@^LRAL)UHGP`?B+?"0@B40D,(GYB?[!X1X/K.X"B<B)\8G&"<Z+
M3"0XB70D2`.,)`@!``")]1.<)`P!``")R(M,)%@%F7F"6HG:@](`,?&+="0H
M,=LASC-T)$")\0'!BT0D,!'3BU0D-(E,)"")QHE<)"0/K-`;P>8%BU0D+,=$
M)"0`````B<$)\8G(BTPD(`'!BT0D*#'_B<Z)3"18B<$/K-`"BU0D0,'A'HG+
M"<,#E"00`0``B="+5"0TB5PD0`69>8):,=TC;"0P,VPD2(GI`<&)\,'@!8E$
M)"")\(ML)"`/K/@;B40D*(M$)#`+;"0H`>F)3"1@B4PD((G!#ZS0`HM4)$C!
MX1Z)S8M,)$P)Q8EL)#@#E"08`0``B=`3C"0<`0``BVPD0`6AZ]ENB<J+7"0X
M@](`B40D*(M$)"")5"0LBU0D6#'K,=HQVXG1`TPD*(M4)"2)3"0HB<$37"0L
MP>$%B5PD+(E,)#")T8G"#ZS*&XM,)##'1"0L`````(E4)$`+3"1`B?*)R(M,
M)"@!P0^L_@+!XAZ)\(E,)"B)UHN4)"`!``")3"1(BXPD)`$```G&@<*AZ]EN
MB70D0(/1`(G0,=N)R@'HBVPD8(M,)"P1VHM<)#@Q_S'S,=V)RXGN`<81UXM4
M)"B)="0PB7PD-(G7B='!YP4/K-D;B?T)S8M,)#`!Z8E,)%B+="0@BWPD)(M<
M)$B)3"0PB?''1"0T`````(N4)#`!``#!X1X/K/X"BWPD+,=$)"0`````B<V+
M3"0X"?6+M"0H`0``B6PD.('&H>O9;HGP`<B+3"1`,>DQRXM,)#")WHM<)#0!
MQHG(P>`%#ZS9&XE$)""+;"0@BT0D0`G-`>Z)="0@B70D2(MT)"B)\0^L_@*+
M?"18P>$>B<N+C"0T`0``"?.!PJ'KV6Z+="0X@]$`B=V)RXG1,=(!R!':,>XQ
MVS'WB?D!P8M$)"`1TXM4)"2)3"0HB<:)7"0LBTPD*`^LT!O!Y@7'1"0L````
M`(G#BT0D,`GS`=F)3"1`B4PD*(M4)#2)P<'A'HMT)$C'1"0T``````^LT`*+
M5"0L"<&+1"0XB<^+C"0X`0``B7PD6('!H>O9;@'(B?DQZ3'.B?$!P8M$)"C!
MX`6)1"0PBT0D*(MT)#`/K-`;BU0D),=$)"0`````B40D.(M$)"`+="0X`?&)
M3"0PB4PD2(G!#ZS0`HM4)#3!X1Z)SHN,)$`!```)QHGHB?V!P:'KV6Z)="0X
M`<@Q]8MT)$`Q[HGQ`<&+1"0PB<Z)P<'A!8E,)"")T8G"BUPD(`^LRAN+1"0H
MB?&)5"1`"UPD0`'9BU0D+(G&B4PD0(E,)"")P0^LU@+!X1Z)RPGSB[0D2`$`
M`(N\)$P!``"+1"18B=V!QJ'KV6Z#UP`QT@'PBW0D.!'ZBWPD2#';,>XQ]XGY
M`<&+1"0@$=.+5"0DB4PD*(G&B5PD+`^LT!O!Y@6+5"0TQT0D+`````")P<=$
M)#0`````"?&+="1`B<B+3"0H`<&+1"0PB4PD*(E,)$B)P0^LT`*+E"10`0``
MP>$>B<L)PXM$)#B!PJ'KV6Z)WP'0,>N+5"0LB7PD6#'>B?$!P8M$)"C!X`6)
M1"0PBT0D*(MT)#`/K-`;BU0D)(E$)#B+1"0@"W0D.`'QB4PD0(E,)#")P0^L
MT`*+E"18`0``P>$>B<X)QH'"H>O9;HGHB?T!T(ET)#@Q]8MT)$B+5"0TB[PD
M9`$``,=$)"0`````,>Z)\0'!BT0D,(G.B<'!X06)3"0@B=&)P@^LRAN+3"0@
MB50D2`M,)$B)R(GQBU0D+`'!BT0D*(E,)$B)3"0@B<&)QHM$)%C!X1X/K-8"
MB<T)]8NT)&`!``"!QJ'KV6Z#UP`QT@'PBW0D.!'ZBWPD0#';,>XQ]XGY`<&+
M1"0@$=.+5"0DB4PD*(G&B5PD+`^LT!O!Y@6+5"0TQT0D+`````")P0GQBW0D
M2(G(BTPD*`'!BT0D,(E,)"B)3"1`B<$/K-`"BY0D:`$``,'A'HG+"<.+1"0X
M@<*AZ]ENB=\!T#'K,=Z)\0'!BT0D*,'@!8E$)#"+1"0HBU0D+(MT)##'1"0T
M`````(E\)%@/K-`;BU0D),=$)"0`````B40D.(M$)"`+="0X`?&)3"1(B4PD
M,(G!#ZS0`HN4)'`!``#!X1Z)S@G&@<*AZ]ENB>B)_0'0B70D.#'UBW0D0(M4
M)#2+O"1\`0``,>Z)\0'!BT0D,(G.B<'!X06)3"0@B=&)P@^LRAN+3"0@B50D
M0`M,)$")R(GQBU0D+`'!BT0D*(E,)$")3"0@B<&)QHM$)%C!X1X/K-8"B<T)
M]8NT)'@!``"!QJ'KV6Z#UP`QT@'PBW0D.!'ZBWPD2#';,>XQ]XGY`<$1TXE,
M)"B)7"0LBT0D((M4)"3'1"0L`````(G&#ZS0&\'F!8M4)#3'1"0T`````(G!
M"?&+="1`B<B+3"0H`<&+1"0PB4PD2(E,)"B)P0^LT`*+E"2``0``P>$>B<L)
MPXM$)#B!PJ'KV6Z)WP'0,>N+5"0LB7PD6#'>B?$!P8M$)"C!X`6)1"0PBT0D
M*(MT)#`/K-`;BU0D)(E$)#B+1"0@"W0D.`'QB4PD,(E,)$")P0^LT`*+E"2(
M`0``P>$>B<X)QH'"H>O9;HGHB?T!T(ET)#@Q]8MT)$B+5"0T,>Z)\0'!BT0D
M,(G.B<'!X06)3"0@B=&)P@^LRAN+3"0@B50D2`M,)$B)R(GQBU0D+(N\))0!
M```!P8M$)"C'1"0D`````(E,)$B)3"0@B<&)QHM$)%C!X1X/K-8"B<T)]8NT
M))`!``"!QJ'KV6Z#UP`QT@'PBW0D.!'ZBWPD0#';,>XQ]XGY`<&+1"0@$=.+
M5"0DB4PD*(G&B5PD+`^LT!O!Y@6+5"0TQT0D+`````")P0GQBW0D2(G(BTPD
M*`'!BT0D,(E,)"B)3"18B<$/K-`"BY0DF`$``,'A'HG+"<.+1"0X@<*AZ]EN
MB=\!T#'KBU0D+#'>B?$!P8M$)"C!X`6)1"0PBT0D*(MT)#`/K-`;B40D.`MT
M)#@!\8E,)$B)3"0PBT0D((M4)"3'1"0T`````(G!B7PD;`^LT`+!X1Z+E"2@
M`0``QT0D/`````")S@G&@<*AZ]ENB>B)_0'0B70D0#'UBW0D6(M4)#2+?"0H
M,>Z+;"0LB?$!P8M$)#")SHG!P>$%B4PD((G1B<(/K,H;BTPD((E4)#@+3"0X
MB?J)R(GQB?X!P<'B'@^L[@*)U8N4)*@!``")3"0XB4PD8(N,)*P!```)]8'"
MH>O9;HEL)%B#T0")T#';B<J+3"1L`<B+3"1`$=J+7"1(,?\QZ3'+B=F)^P'!
M$=.+5"0XB4PD((M,)#R)7"0DB=?'1"0D`````,'G!8G+B=$/K-D;B?X)SHGP
M`T0D((E$)""+="0PBWPD-,=$)$P`````B?''1"0T`````,'A'@^L_@*)RXN,
M)+`!```)\XG=@<&AZ]ENB5PD2(N<)+0!``")R(M,)$"#TP")VC';`<B+3"18
M$=J+7"1@,?\QZ3'+B=F)^XM\)#S'1"0\``````'!B4PD*(M,)"`1TXE<)"R+
M7"0DB<B)RL=$)"P`````P>`%#ZS:&XG&"=:+5"0LB?"+="0X`T0D*(E$)"B)
M\0^L_@+!X1Z)\(G.BXPDN`$```G&BT0D6('!W+P;CXGWB70D.`'(B70D6`GU
MBW0D2"-L)"`A_@GUB>D!P8M$)"B)QHG'P>8%#ZS7&XET)#"+="0P"?Z)\`'(
MB40D,(M,)""+7"0DBWPD3,=$)$0`````B<C'1"1,`````,'@'@^LV0(QVXG"
MBT0D*`G*BTPD6(G5B50D0`G1BU0D."'((>J)Q@G6B?&+="1(`[0DP`$``(GP
M$[PDQ`$``(GZ!=R\&X^#T@`!P8M$)#`1TXM4)#2)3"0@B<:)7"0DBUPD+`^L
MT!O!Y@6)P0GQB<B+3"0H`T0D(#'_B<:)R`^LV0+!X!Z)PHM$)#@)RHG1"=6)
M5"1((VPD,(E4)%B+5"1`(<H)U0.$),@!``")Z07<O!N/`<&)\,'@!8E$)"")
M\(ML)"`/K/@;B40D*`ML)"B)Z`'(B40D((M,)#"+7"0TBU0D2,=$)"0`````
MB<C'1"0\`````,'@'@^LV0(QVXG%"<V+3"18(>J);"0X">F)R"'P"="+5"1$
MQT0D1`````")P8M$)$`#A"30`0``$Y0DU`$```7<O!N/@](``<&+1"0@$=.)
M3"0HBU0D)(G!B5PD+,'A!<=$)"P`````B4PD,(G1B<(/K,H;BTPD,(E4)$`+
M3"1`B<B)\0-$)"C!X1Z)1"0HB<B)\8MT)$@/K/D"B<()RHG1"=6)5"1`(VPD
M((E4)%B+5"0X(<H)U0.T)-@!``"+?"0HQT0D-`````")\(GIBVPD+(M<)"0%
MW+P;CXM4)$#'1"1,``````'!B?@/K.\;QT0D)`````#!X`7'1"0\`````(E$
M)#"+="0P"?Z)\(MT)#@!R(M,)"")1"0PB<@/K-D"BUPD+,'@'HG%BT0D*`G-
MBTPD6"'JB6PD2`GI(<@)T`.T).`!``"+5"0TB<&)\`7<O!N/`<&+1"0PB<8/
MK-`;B40D(,'F!0MT)"")\(MT)$`!R(M,)"B)1"0@B<@/K-D"P>`>B<()RHG1
M"=6)5"0X(VPD,(E4)%B+5"1((<H)U0.T).@!``")\(GI!=R\&X\!P8M$)""+
M5"0DQT0D+`````"+;"0TQT0D-`````")QHG'P>8%#ZS7&XM4)#B)="0HBW0D
M*`G^BWPD,(GP`<B)^3';P>$>B40D*(G(B?F+?"1,#ZSI`HG%BT0D(`G-BTPD
M6"'JB6PD,`GI(<B)Q@G6B?&+="1(`[0D\`$``(GP$[PD]`$``(GZ!=R\&X^#
MT@`!P8M$)"@1TXM4)"R)3"1`B<:)7"1$BUPD)`^LT!O!Y@7'1"1$`````(G!
M"?&)R(M,)"`#1"1`,?^)QHG(#ZS9`L'@'HG"BT0D.`G*B=$)U8E4)$`C;"0H
MB50D2(M4)#`AR@G5`X0D^`$``(M<)"S'1"0D`````(GI!=R\&X^+5"1`QT0D
M/``````!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0X"VPD.(GH`<B+3"0HB40D
M((G(#ZS9`C';P>`>B<4)S8M,)$@AZHEL)#@)Z8G((?`)T(M4)#2)P8M$)#`#
MA"0``@``$Y0D!`(```7<O!N/@](``<&+1"0@$=.)3"0HBU0D)(G!B5PD+,'A
M!<=$)"P`````B4PD,(G1B<(/K,H;BTPD,(E4)$@+3"1(B<B)\0-$)"C!X1Z)
M1"0HB<B)\0^L^0*)P@G*B=$)U8E4)$C'1"1,`````"-L)""+="1`BWPD*(E4
M)%B+5"0XBUPD),=$)#0`````QT0D1``````ARL=$)"0`````"=4#M"0(`@``
MBU0D2,=$)#P`````B?")Z8ML)"P%W+P;CP'!B?@/K.\;P>`%B40D,(MT)#`)
M_HGPBW0D.`'(BTPD((E$)#")R`^LV0*+7"0LP>`>B<6+1"0H"<V+3"18(>J)
M;"1`">DAR`G0`[0D$`(``(M4)#2)P8GP!=R\&X\!P8M$)#")Q@^LT!N)1"0@
MP>8%"W0D((GP`<B+3"0HB40D((G(#ZS9`L'@'HG""<J)T0G5B50D.(E4)%B+
M5"1`(VPD,(MT)$C'1"0L`````"'*"=4#M"08`@``BU0D)(GPB>F+;"0TQT0D
M-``````%W+P;CP'!BT0D((G&B<?!Y@4/K-<;BU0D.(ET)"B+="0H"?Z+?"0P
MB?`!R(GY,=O!X1Z)1"0HB<B)^8M\)$0/K.D"B<6+1"0@"<V+3"18(>J);"0P
M">DAR(G&"=:)\8MT)$`#M"0@`@``B?`3O"0D`@``B?H%W+P;CX/2``'!BT0D
M*!'3BU0D+(E,)$")QHE<)$2+7"0D#ZS0&\'F!8G!"?&)R(M,)"`#1"1`,?^)
MQHG(#ZS9`L'@'HG""<J)T0G5B50D0,=$)$0`````(VPD*(M$)#B+7"0LB50D
M2(M4)##'1"0D`````,=$)#P`````(<H)U0.$)"@"``"+5"1`B>D%W+P;CP'!
MB?#!X`6)1"0@B?"+;"0@#ZSX&XE$)#@+;"0XB>@!R(M,)"B)1"0@B<@/K-D"
M,=O!X!Z)Q0G-BTPD2"'JB6PD.`GIB<@A\`G0BU0D-(G!BT0D,`.$)#`"```3
ME"0T`@``!=R\&X^#T@`!P8M$)"`1TXE,)"B+5"0DB<&)7"0LP>$%B4PD,(G1
MB<(/K,H;BTPD,(E4)$@+3"1(B<B)\0-$)"B+5"0XP>$>B40D*(M<)"2)R(GQ
MQT0D+``````/K/D"B<:+?"0HQT0D-``````)SL=$)$0`````(?()]2-L)"")
M="0PB=")ZHET)$B+="1`"<(#M"0X`@``BVPD+(GPB=$%W+P;CP'!B?@/K.\;
MP>`%B40D0(MT)$`)_HGP`<B+3"0@,?^)QHG(#ZS9`C';P>`>B<*+1"0H"<J+
M3"1(B=6)5"1`"=&+5"0P(<@AZ@G0BU0D/(G!BT0D.`.$)$`"```3E"1$`@``
M!=R\&X^#T@`!P8GP$=/!X`6)3"0@B<&)\(E<)"0/K/@;B40D.`M,)#B)R`-$
M)""+3"0HQT0D)`````")1"0@BUPD+(G(QT0D+`````#!X!X/K-D",=O'1"0\
M`````(G"BT0D,`G*B=&)5"0H"=6)5"1@BU0D0"'U(<H)U0.$)$@"``"+5"0T
MB>D3E"1,`@``!=R\&X^#T@`!P8M$)"`1TXE,)#"+5"0DB<&)7"0TP>$%QT0D
M-`````")3"0XB=&)PHM<)#@/K,H;BTPD,(M$)"")5"1("UPD2`'9BU0D*#';
MB4PD6(E,)#")\0^L_@+!X1Z)S8M,)&`)]0GI(>J);"0X(<B)Q@G6B?&+="1`
MBWPD1`.T)%`"```3O"14`@``B?")^@7<O!N/@](``<&+1"0P$=.+5"0TB4PD
M0(G&B5PD1(M\)$0/K-`;P>8%,=*)PXM$)"`)\XMT)$")P0'>$=>+5"0DP>$>
MB70D8(G+B7PD9(M,)"@Q_P^LT`()PP.,)%@"``")7"1(B<B+7"0L$YPD7`(`
M``76P6+*B=J)1"0@B?"#T@`S;"1(B50D)(M4)%@QZHG1`TPD(,'@!8E$)"")
M\(ML)"`/K/@;B40D*`ML)"@!Z8E,)%B)3"0@QT0D)`````"+1"0PBU0D-(M<
M)#R)P<'A'@^LT`*)S8M,)#@)Q0.,)&`"```3G"1D`@``B<B)VHEL)$"+;"1(
M!=;!8LJ+3"1`@](`B40D*(M$)"`QVXE4)"R+5"1@,>DQRHG1`TPD*(M4)"2)
M3"0HB<$37"0LP>$%B5PD+(E,)#")T8G"#ZS*&\'I&\=$)"P`````B50D.(GR
MB4PD/(M,)#`+3"0XB<B+3"0H`<$/K/X"P>(>B?")3"1(B=:+E"1H`@``B4PD
M*(N,)&P"```)QH'"UL%BRHET)#B#T0")T#';B<H!Z(M,)$`1VHM<)%@Q_S'Q
M,<N+3"0LB=X!QHG+$=>+5"0HB70D,(E\)#2)UXG1QT0D-`````"+5"0LP><%
M#ZS9&XM<)$B)_HM\)"3'1"0D``````G.B?"+="0P`<:)="18B70D,(MT)"")
M\0^L_@+!X1X)\8G.BXPD<`(``('!UL%BRHG(BTPD0(ET)$`!R(M,)#@Q\3'+
MBTPD,(G>BUPD-`'&B<C!X`4/K-D;BUPD0(E$)""+1"0HBVPD(`G-B<$![L'A
M'@^LT`*)S8N4)'@"``")="0@"<6+1"0X@<+6P6+*B6PD.`'0,>N+;"18,=V)
MZ0'!BT0D(,'@!8E$)"B+1"0@BU0D)(ML)"C'1"0L``````^LT!N+5"0TQT0D
M-`````")1"1(BT0D,`ML)$@!Z8E,)$B)3"0HB<$/K-`"BU0D+,'A'@G!BT0D
M0(G-BXPD@`(``(EL)$"!P=;!8LH!R(M,)#@QZ8G-,?6)Z0'!BT0D*(G&B<>+
M1"0@P>8%#ZS7&XM4)"2)="0PBW0D,`G^BWPD-`'QB<:)3"0P#ZS6`HE,)%B)
MP8GPP>$>B<Z+C"2(`@``"<:+1"0XB?6+="1`@<'6P6+*`<B);"0X,>Z+;"1(
M,?6+="0PB>F)_0'!B?")]\'@!0^L[QN)1"0@BW0D(`G^`?&)3"0@BT0D*(G.
MBU0D+(ML)%C'1"0D`````(G!QT0D+`````#!X1X/K-`"BU0D)(G+BXPDD`(`
M``G#BT0D0('!UL%BRHE<)$`!R(M,)#@QV3'-B>D!P8M$)"#!X`6)1"0HBT0D
M((ML)"@/K-`;BU0D-,=$)#0`````B40D2(M$)#`+;"1(`>F)3"0HB4PD2(G!
M#ZS0`HM4)"S!X1Z)S8N,))@"```)Q8M$)#B!P=;!8LJ);"0X`<B+3"1`,>F)
MS3'UB>D!P8M$)"B)QHG'BT0D(,'F!0^LUQN)="0PBW0D,`G^`?&)QL'F'HE,
M)%B)3"0PBU0D)(GQB<:+?"0TQT0D)``````/K-8"BU0D+,=$)"P`````B?")
MS@G&BT0D0(GUB[0DH`(``(EL)$"!QM;!8LH!\(MT)#@Q[HML)$@Q]8MT)#")
MZ8G]`<&)\(GWP>`%#ZSO&XE$)""+="0@BT0D*`G^`?&)3"0@B<Z)P0^LT`+!
MX1Z+5"0D"<&+1"0XB<V+C"2H`@``B6PD.('!UL%BR@'(BTPD0#'IBVPD6#'-
MB>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;BU0D-(E$)$B+1"0P"VPD2`'I
MB4PD2(E,)"B)P0^LT`+!X1Z)S8N,)+`"```)Q8M$)$"+5"0LQT0D-`````"!
MP=;!8LJ);"1``<B+3"0X,>F)S3'UB>D!P8M$)"B)QHG'BT0D(,'F!0^LUQN+
M5"0DQT0D)`````")="0PBW0D,`G^BWPD-`'QB<;!YAZ)3"18B4PD,(GQB<8/
MK-8"BU0D+(GPB<X)QHM$)#B)]8NT)+@"``");"0X@<;6P6+*`?"+="1`,>Z+
M;"1(,?6+="0PB>F)_0'!B?")]\'@!0^L[QN)1"0@BW0D((M$)"@)_@'QB<Z)
M3"0@B<$/K-`"P>$>"<&+1"1`B<V+C"3``@``B6PD0('!UL%BR@'(BTPD.#'I
MBVPD6#'-B>D!P8M$)"#!X`6)1"0HBT0D((M4)"2+;"0HQT0D+``````/K-`;
MBU0D-,=$)#0`````B40D2(M$)#`+;"1(`>F)3"1(B4PD*(G!#ZS0`HM4)"S!
MX1Z)S8N,),@"```)Q8M$)#B!P=;!8LJ);"0X`<B+3"1`,>F)S3'UB>D!P8M$
M)"B)QHG'BT0D(,'F!0^LUQN+5"0DB70D,(MT)#`)_HM\)#0!\8G&P>8>B4PD
M,(E,)%B)\8G&#ZS6`HGPB<X)QHM$)$")]8NT)-`"``");"1`@<;6P6+*`?"+
M="0X,>Z+;"1(,?6+="0PB>F)_0'!B?")]\'@!0^L[QN)1"0@BW0D(`G^`?&)
M3"0@BT0D*(G.BU0D+(N<)-P"``#'1"0D`````(G!QT0D+``````/K-`"P>$>
M"<&+1"0XB<V+C"38`@``B6PD.('!UL%BRH/3`#'2`<B+3"1`$=HQVS'IBVPD
M6#'-B>D!P8M$)"`1TXM4)"3!X`6)1"0HBT0D((ML)"@/K-`;,=*)1"1(BT0D
M,`ML)$@!Z1'3B4PD*(M4)#2)3"1(B<'!X1X/K-`"B5PD3(N<).0"``")S8N,
M).`"```)Q8M$)$"!P=;!8LJ);"1`@],`,=(!R(M,)#@1VC';,>F)S3'UB>D!
MP8M$)"@1TXM4)"R)QHG'P>8%#ZS7&S'2B70D,(MT)#`)_@'Q$=.)3"18B5PD
M7(M$)""+5"0DB4PD,(G&QT0D-`````"+?"0TP>8>QT0D)`````")\8G&#ZS6
M`HM4)"R)\(G."<:+1"0XB?6+M"3H`@``B6PD.('&UL%BR@'PBW0D0#'NBVPD
M2#'UBW0D,(GIB?T!P8GPB??!X`4/K.\;B40D((MT)"`)_HGP`<B)1"0@BT0D
M*(G!#ZS0`HM4)##!X1X)P8G6BT0D0(G-BTPD-,'F'HET)"B+="18B<\/I-<>
M#ZS*`L'I`HE4)#"+5"0DB4PD-(N,)/`"``")?"0L@<'6P6+*`<B+3"0X,>DQ
MSHGQ`<&+1"0@B<8/K-`;B40D0,'F!0MT)$#!ZAN)\(E4)$0!R(G!`TPD$(M$
M)&B+="0HB0B)P<=`!`````"+1"08`T0D(`MT)##'00P`````B4$(B?`#!"2)
M01")Z`-$)`B)01B+1"0X`T0D4,=!%`````#'01P`````B4$@QT$D`````(N$
M)/P"``!E,P44````=0N!Q`P#``!;7E]=P^BJ'P``C;0F`````(UV`%575E/H
M1];__X'#=XX``(/L'(7`#X2>````BXL<`0``BPF)3"0(A<D/A(H````/M@B$
MR70%@/D]=48Q]HM\)`B++X7M="^)5"0,B40D!&:0@^P$5O]T)`Q5Z-+2__^#
MQ!"%P'4'@'PU`#UT+(/'!(LOA>UUVX/$'(GH6UY?7<.0B<:#Q@$/M@Z$R70%
M@/D]=?$IQNNGC78`BT0D#(GZ*U0D"(UL-0'!^@*)$(/$'(GH6UY?7<.-=@"#
MQ!PQ[5N)Z%Y?7<.-M"8`````C70F`)#H<-;__X'"JXT``%=6B<93@^P09:$4
M````B40D##'`B[H<`0``C5PD"(G:B?#H_O[__X7`=#.+5"0(BP>-!)"+4`2)
M$(72=.&-M"8`````D(/`!(M0!(D0A=)U](G:B?#HR_[__X7`=<V+1"0,93,%
M%````'4'@\006UY?P^A.'@``C;0F`````(VT)@````!5B<575HG64^CCU/__
M@<,3C0``@^PX9:$4````B40D*#'`,<"`.CT/E,`!QE;H3M#__X/$$(E$)`2-
M5"08B>CH7/[__X7`#X0$`0``@^P,B<=0Z"G0__^#Q!`[1"0$#X/4````BT0D
M&(T4A0````"+@QP!``")!"0/MD4`A,`/A)P!```\/0^$E`$``(GH9I"#P`$/
MM@B$R70%@/D]=?$IZ(L,)(/L#(LY`=>+5"00C400`E#H9]#__X/$$(D'A<`/
MA&T!``"+#"2+5"08BP&-30&+%)`/MD4`B`(\/70=A,!U">L7C78`/#UT$(/!
M`0^V0?^#P@&(`H3`=>S&`CTQP(VT)@`````/M@P&B$P"`8/``83)=?$QP(M<
M)!QE,QT4````#X43`0``@\0L6UY?7<.-M@`````QP(VV``````^V%`:(%`>#
MP`&$TG7RZ\>+@QP!``"+"(D$)(LYA?\/A,(````QP.L)C;0F`````(GXC7@!
MBQ2YA=)U](T$A0P```"+DW`1``"%TG5KB4PD"(/L#%#'@W`1```!````Z'S/
M__^#Q!"%P`^$A````(/L!(T4O0````!2BTPD$(E4)!11B40D%%#HL\___XM4
M)!"+1"08@\00B0*+5"0,BT0D",=$N`0`````B7PD&.F%_O__C70F`)"#[`A0
M4>@.S?__BU0D$(E$)!B#Q!")`H7`=""-%+T`````Z\*-="8`,<#I>O[__[@(
M````,?_I4/___[C_____Z=S^___H_AL``(VT)@````"-M"8`````58G%5U93
MZ)72__^!P\6*``"![(P```!EH10```")1"1\,<"%[70&@'T``'4CBT0D?&4S
M!10````/A3L!``"!Q(P```!;7E]=PXVT)@````"#[`Q5Z'?-__^)1"00@\00
MA<!TR8V#.:'__XE$)`2-@SBA__^)1"0(@^P,_W0D#.B,S?__@\00A<`/A,$`
M``"-4!.+?"0$N0(```")UO.F#Y?`'`"$P'30BWPD"+D#````B=;SI@^7P!P`
MA,!TNHE4)`R#[`Q5Z&7-__^+5"0<B<:)%"2)5"0<Z%/-__^-1`8"B00DZ.?-
M__^)QEB-@SNA__]:BU0D%%)54&K_:@%6Z%S.__^#Q!R-1"0@4%9J`^B\R___
M@\00@_C_=!"+1"0L)0#P```]`$```'1$@^P,5N@+S?__@\00@^P,5NA?S/__
M@\00Z2____^-M"8`````@^P,_W0D#.@TS?__B2PDZ)S-__^#Q!#IP?[__XUT
M)@")\.B)_O__Z[_H<AH``&:05HG&4^@7T?__@<-'B0``@^QX9:$4````B40D
M<#'`C40D$%!6:@/H!<S__X/$$(7`=3:+5"0<@>(`\```@?H`0```=`B!^@"@
M``!U'H/L"&H"5NCIR___@\00A<`/E,`/ML#K!HUT)@`QP(M,)&QE,PT4````
M=0:#Q'1;7L/H[AD``(VT)@````"-M"8`````55>)QU93Z(70__^!P[6(``"!
M[#`0``")5"0,9:$4````B80D(!```#'`:/\/``"-@T&A__^-="0D5E#HT,S_
M_X/$$(7`?G&-:/^+D_P```"`?"P<`(L2=5>%[71CB50D#(/L!%5J+U;H\\S_
M_X/$$(M4)`R%P'1(@^P,4NC?RO__55974.C&R___@\0@BX0D'!```&4S!10`
M``!U/X'$+!```%M>7UW#C;0F`````)")Q>NIC70F`(N#_````(L0@^P,4NB7
MRO__@\0,_W0D#%=0Z%G*__^#Q!#KL>C_&```C;0F`````(VT)@````"04^B:
MS___@</*AP``@^P4BX/\````_S#H5,K__XV3-*/__U*-DU"A____LQ`!``!2
M4.AJS/__@\0H6\.-="8`D%93Z%G/__^!PXF'``"#[!"+L_P```#_-N@3RO__
MB00DZ)O___]8_S;H`\K__UJ-D^6B__]9:@!24HV3@(S__U*-DVRA__]24.AC
MRO__@\0D6U[#C;0F`````(VV`````%575E/H]\[__X'#)X<``('L'"```&6A
M%````(F$)`P@```QP.B'R/__@^P(C9-,H?__4E"-@X&A__]0:`$0``!J`8UT
M)"96Z'3+__^#Q!QH`!```(V\)!,0``!75C'VZ!S+__^#Q!"%P'@I@^P,B<6-
M0`%0Z+?*__^#Q!")QH7`=!*#[`155U#H\\G__\8$+@"#Q!"+C"0,(```93,-
M%````(GP=0N!Q!P@``!;7E]=P^B:%P``C;0F`````(UV`.D[____C;0F````
M`(UT)@!55U93Z"?.__^!PU>&``"![)P0``"+O"2P$```B[0DM!```(E\)!!E
MH10```")A"2,$```,<"-1"0LB40D%(G"C8.-H?__Z)7W__^#[`AJ+XG%5^@8
MR/__@\00A<!T.8M\)!"-@Y:A__^)^NC0^/__B?B+C"2,$```93,-%`````^%
M>@$``('$G!```%M>7UW#C;0F`````(/L#/]T)!SH',G__UI9B40D((V#HZ'_
M_XE$)!105NCER?__@\00B<:-@SFA__^)1"0<C;8`````A?9TBX`^``^$PP``
M`(7M=!6#[`A65>AURO__@\00A<`/A(L```"#[`Q6Z,'(__^#Q!"`?`;_+W45
MC;0F`````(/H`8!\!O\OQ@0&`'3RBU0D&(U$$`$]_P\```^/+O___X/L!(V#
MI:'___]T)!10C8.@HO__5E!H`!```&H!C;0DJ````%;HE<G__X/$'/]T)!A6
M:@/H]L;__X/$$(7`=1"+1"0\)0#P```]`(```'1/@^P(_W0D%&H`Z!')__^#
MQ!")QNDW____C;0F`````(7M=!R+?"0<N0(```")[O.F#Y?`'`"$P'3'C;8`
M````BW0D'+@!````Z5#___]FD(/L"&H!5NAUQ___@\00A<!UGXGRC8.6H?__
MZ%'W__^#[`Q6Z%C)__^#Q!#I<O[__^A[%0``C;0F`````(UT)@"+5"0$#[8*
MB="$R70;C78`@\(!@/DO#[8*#T3"A,EU\,.-M"8`````PXVT)@````!64^CI
MR___@<,9A```@^P$BW0D$(7V#X2D````@#X`#X2;````@^P,5NA2Q___@\00
MC40&_SG&<@[K(8UT)@"0@^@!.<9T&8`X+W3TZP=FD(`X+W0P@^@!.<9R]#G&
M=26`."]T6X/L#(V#I:'__U#HG,C__X/$$(/$!%M>PXUV`(`X+W4'@^@!.<9R
M]"GPC4@"B<(QP('Y`!```'<;C4(!:``0``!05HVS<`$``%;H+<7__X/$$(GP
M@\0$6U[#9I"#[`R-@SFA__]0Z$'(__^#Q!"#Q`1;7L.-M"8`````D%=64^@(
MR___@<,X@P``@^PP9:$4````B40D+#'`C70D!(N#$*/__XE$)`J+@Q2C__^)
M1"0.BX,8H___B40D$HN#'*/__XE$)!:+@R"C__^)1"0:BX,DH___B40D'HN#
M**/__XE$)"*+@RRC__^)1"0F#[>#,*/__V:)1"0JC8.GH?__Z`CU__^-@["A
M___H_?3__XV#N*'__^CR]/__C8/!H?__Z.?T__^-@\BA___HW/3__XV#V*'_
M_^C1]/__C8.-H?__Z,;T__^-@^2A___HN_3__XV#[J'__^BP]/__C8/XH?__
MZ*7T__^-@Y:A___HFO3__XGRC8,"HO__Z+WS__^%P'0-B<*-@^ZA___H#/7_
M_XGRC8,3HO__Z)_S__^%P'0-B<*-@R6B___H[O3__XGRC8,PHO__Z('S__^%
MP'0UB<*-@XVA___HT/3__XV37*+__XV#R*'__^B_]/__BT0D+&4S!10```!U
M78/$,%M>7\.-=@")\HV#0*+__^@[\___A<!T%XG"C8/DH?__Z(KT___KN(VT
M)@````"0C70D&[D*````C;M1HO__\Z8/E\`<`(3`=9:-5"0EC8/DH?__Z%?T
M___KA>B0$@``4^@ZR?__@<-J@0``@^P89:$4````B40D##'`BX,X`0``@_C_
M=!J+3"0,93,-%````'4^@\086\.-M"8`````D(U4)`B-@^2A___HH?+__XG"
M,<"%TG02#[82@/HP#Y7!,<"$T@^5P"'(B8,X`0``Z[7H&A(``(VT)@````"-
M=@!3Z+K(__^!P^J```"#[`CH?,3__X/L#%#H4\3__X/$$(7`=`R+`(/$"%O#
MC70F`)"#Q`@QP%O#C;0F`````&:055=64^AWR/__@<.G@```@^P<9:$4````
MB40D##'`C50D"(M\)#"-@UZB___H__'__X7`=`>`.`")QG4DB?J-@UZB___H
M1_/__XM$)`QE,P44````=6N#Q!Q;7E]=PV:0@^P(5U#H-L3__X/$$(7`==B#
M[`Q7Z);#__^)-"2)Q>B,P___C40%`HD$).@@Q/__@\0,B<6-@Z.A__]64(V#
MH*+__U=0:O]J`57HD<3__X/$((GJC8->HO__Z-'R___KB.@*$0``C;0F````
M`(UV`.B@R/__@<+;?P``55=64X'LC($``(G1BX0DH($``(E4)`B-="0PC9EN
MHO__B40D%&6A%````(F$)'R!```QP(V">J+__XF<))P```")A"20````C8(Y
MH?__C9(EHO__B80DE````(V!'J+__XF$)*P```"-@7^B__^)A"2P````C8$[
MHO__B80DM````(V!AZ+__XF$)+@```"-@8NB__^)5"00B90DJ````(GRB80D
MH````(V!C:'__\>$))@`````````QX0DO`````````#'A"2D`````````.B`
M\/__A<!T"8`X``^%\P0``.C^_?__B<6%P`^$=`0``(/L#%6+?"08B?OH-<+_
M_XU$``&)!"3HR<+__XE$)!R#Q!"`?0``=$:+1"0(BWPD#(ET)""-@)2B__^)
M_HG'C;8`````#[9%`(/L#(/%`5!7:O]J`5:+7"0H@\8"Z!/#__^#Q""`?0``
M==J+="0@C9PDJ````(M$)!#K%HVT)@````!FD(/#!(L#A<`/A),!``")\NC,
M[___B<>%P'3F@#@`=.'H[/3__X7`=-B#[`Q7BUPD&.@;P___@\00B<6%P`^$
M7@$``(VV`````(GIBQ&#P02-@O_^_O[WTB'0)8"`@(!TZHG"P>H0J8"````/
M1,*-40(/1,J)P@#"BU0D#(/9`RGIBQJ#P@2-@__^_O[WTR'8)8"`@(!TZHG#
MP>L0J8"````/1,.-6@(/1-.)PP##@]H#*U0D#(/L#(V\$00$``!7BUPD&.B8
MP?___W0D'(M,)!R)PHV!F:+__XG+4(V!I:'__XE$)"A0C8&>HO__55!J_VH!
MB50D.%+H],'__X/$*&C``0``_W0D&.CCOO__@\00@_C_=1#HMK[__XL`@_@1
M#X44`P``@^P$5O]T)!1J`XM<)!CH",#__X/$$(G%A<`/A*L```"#[`S_="08
MBT0D)/\PBUPD'(V#?*/__U"+@Q@!``!J`?\PZ-2^__^#Q"#'1"0@`````(N,
M)'R!``!E,PT4````BT0D(`^%0PD``('$C($``%M>7UW#C;8`````,?^-M@``
M``"+G+R0````A=MT-8`[`'0PB=B#QP'H3O/__X7`=.*#[`Q3BUPD&.A]P?__
M@\00A<!TSHG%Z6?^__^-M"8`````,>WI6?[__Y"+1"1`)0#P```]`$````^%
M0?___XM$)$B+7"0(B40D(.CKO___.40D(`^%)O___XM$)$`E_P$``#W``0``
M#X42____@^P,5XM\)!B)^^@>P/__B?*)1"0PC8=IHO__Z(WM__^#Q!"%P`^$
M4@(``(/L#%"+7"08Z.7`__]:65"+1"0@_S#HA_7__XE$)"B#Q!"%P`^$*`(`
M`(/L#(M\)"17BUPD&.@GO___@\00@_@#=C^+5"0(C70'_(G[N04```"-NJ>B
M___SI@^7PH#:`(32=1Z#^`0/A*@&``"`?`/[+P^$G08``(VT)@````"-=@#H
M"_K__X7`=2&#[`AJ`/]T)"2+7"08Z"7`__^)1"0T@\00A<`/A;4!``"+?"0(
MC9=<HO__B?N-A^2A___H'^[__XVWY:+__^BTO/__5E"-A\"B__^-O\ZB____
M="08_W0D&%!J_VH!_W0D/.B@O___@\0@B70D%(MT)"#K0(UV`(M<)`CH9[S_
M_X,X$75)BUPD"(/%`>AFO/__@^P,_W0D(%50_W0D*/]T)"A7:O]J`5:+7"0X
MZ%:___^#Q#"#[`AHP`$``%:+7"08Z$&\__^#Q!"#^/]TJ8/L#/]T)!B+?"08
MB?OH9[W__XM<)#"-AXVA__^)VNAF[?__B1PDZ,[Y__^#Q!#IC?W__XVV````
M`(G8,?_K$8VT)@````"-=@"+A+R<````A<!T?HGR@\<!Z,OK__^%P'3G@#@`
M=.*#[`Q0BUPD&.@EO___@\00A<!TSHG%Z4/[__^#[`A0_W0D&(M$)"3_,(M<
M)!R-@T"C___I!OW__XVT)@````"-=@"#[`Q0B40D'.A#^?__BT0D'(M<)!B)
M!"3HT[[__XE$)#"#Q!#I[OS__X/L#&H-BWPD&(G[C:]SHO__Z,&]__^)1"0<
M@\00Z?GZ__^-="8`D(M$)!2+`(E$)!CIR?W__VH":O]J[HMT)#!6BWPD&(G[
MZ+N[__^#Q`QJ!HV$)(0!``")1"0<4%;H)+S__X/$$("\)'P!````=0Z`O"1]
M`0``0P^$004``&H`:@!J`/]T)#"+7"08Z':[___'A"30`````2-%9\>$)-0`
M````````QX0DV````(FKS>_'A"3<`````````,>$).````#^W+J8QX0DY```
M``````#'A"3H````=E0R$,>$).P`````````QX0D\````/#ATL/'A"3T````
M`````,>$)/@`````````QX0D_`````````#'A"0``0```````,>$)`0!````
M````QX0D2`$```````"#Q!"-A"3`````B40D+(V$)/@```")1"0HC;0F````
M`)"#[`1H`(```/]T)!S_="0PBUPD&.@7N___@\00B<:%P`^.XP$``(GPB?&)
M="08B[PD\````)G!X0.X``````.,).@````[C"3H````&X0D[````(E4)!R+
MK"3T````<P:#QP&#U0"+5"0<BT0D&(F,).@```#'A"3L``````````^LT!W!
MZAT!^(F$)/````"+A"0X`0``$>J)E"3T````A<`/A%@!``"]0````"G%.>X/
M3NX#1"0H@^P$5?]T)!Q0BUPD&.@&N___BX0D2`$```'HB80D2`$``(/$$(/X
M0`^%&O___XM$)"PI[@-L)!3H6\#__X/^/P^.[0(``(/N0(GWB70D&(GNP>\&
MC5\!P>,&`>N+;"0LC;0F`````)"+!H/&0(F$)/@```"+1L2)A"3\````BT;(
MB80D``$``(M&S(F$)`0!``"+1M")A"0(`0``BT;4B80D#`$``(M&V(F$)!`!
M``"+1MR)A"04`0``BT;@B80D&`$``(M&Y(F$)!P!``"+1NB)A"0@`0``BT;L
MB80D)`$``(M&\(F$)"@!``"+1O2)A"0L`0``BT;XB80D,`$``(M&_(F$)#0!
M``")Z.B'O___.?,/A4____^+="08P><&*?YJ1%93_W0D-(M<)!CH);G__XFT
M)$@!``"#Q!#I!O[__XVV`````(ML)!3I[/[__X/L#/]T)#"+7"08Z#>Z__^+
MA"3X````BY0D_````(NL)/@```"+M"0``0``#ZS0`X/@/P_-#\Z-2`'&A`0(
M`0``@(/$$(/Y.`^.FP$``(M4)"BX0`````'**<B)P70-,<#&!`(`@\`!.<AR
M]8M$)"SHTK[__XM\)"BY#@```#'`\ZN+1"0LB;0D,`$``(V\)'L!``"-M"1`
M`0``B:PD-`$``.B@OO__BY0DP````(V,)%,!``")?"04B4PD&(G-BTPD"(GW
M#\J)E"0_`0``BY0DR````(V)E*+__P^VA"3#````#\J)E"1#`0``BY0DT```
M`(G.#\J)E"1'`0``BY0DV`````_*B90D2P$``(N4).`````/RHF4)$\!``#K
M#8VT)@`````/M@>#QP&#[`P/ML!05FK_:@%5BUPD*(/%`NC!N?__@\0@.6PD
M%'78BUPD",:$)'L!````C8/EHO__4(V#L:+___]T)!S_="08_W0D&%!J_VH!
M_W0D/.B%N?__@\0@Z43Z__^+1"04BU`$A=(/A%[Y__^#[`Q2BWPD&(G[B50D
M).@KN/__@\00@_@##X8_^?__BU0D%+D%````C;^LHO__C70"_/.F#Y?`'`"$
MP`]%5"08B50D&.D5^?__B>OIZ/W__[HX````BT0D*#';*<H!R(/Z!',JA=(/
MA'W^___&``#VP@(/A''^__\QR6:)3!#^Z67^__^-M"8`````C78`C4@$QP``
M````@^'\QT00_``````IR`'0@^#\@_@$#X(W_O__@^#\,=*)'!&#P@0YPG+V
MZ2/^__^`O"1^`0``00^%L?K__X"\)'\!``!##X6C^O__@+PD@`$``$@/A97Z
M__^`O"2!`0``10^%A_K__VH":O]JQHML)#!5BWPD&(G[Z/JU__^#Q`QJ*8MT
M)!Q65>AJMO__C8?EHO__4(V'L:+__U;_="0H_W0D*%!J_VH!_W0D3.@FN/__
M@\0PZ>7X___HJ00``(VT)@````!FD%575E/H1[O__X'#=W,``(/L.&6A%```
M`(E$)"@QP(N[_````/\WZ/6U__]=_S>)QNCKM?__#[96:(A0:8U$)"B)1"0<
MB<*-@\BA___HK^3__X/$$(7`=`F`.#$/A*\"``#HVN___X/L#/\WZ+"U__^-
MD]^B__]J"VH!4E#H7[7__X/$((7`#X3^````BT`,@[MX$0```8LOBT`8B40D
M"`^.YP```#'VZSV-M"8`````BT(,@^P(C58!4(N#=!$``/\TD(E4)!3HM+?_
M_X/$$(N+>!$``(7`=6^#Q@*+5"0$.?&)UGYB@^P,5>@QM?__:@!6_W0D(%#H
M-+;__X/$((7`=#V+$(LOBT(()0`$(``]``0``'2:B50D!(/L#%7H_;3__VH"
M:@"+5"0<4E#H;K?__XLO@\0@Z7?___^-="8`BXMX$0``BR^-0?\Y\'4]@_D!
M?CB)Z+X!````BVPD".L)C;0F`````(L'@^P,@\8!4.BJM/__6EE54.A1M/__
M@\00.;-X$0``?]Z++X/L#%7HB[3__XV3Y*+__VH#:@%24.@ZM/__@\0@B<:%
MP'0RBT`,@^P,BRC_-^ABM/__@\0,C9/FHO__4E50Z"&T__^+1@R#Q!"+,/9&
M"D`/A6<!``"#[`S_-^@UM/__C9/KHO__:@-J`5)0Z.2S__^#Q"")QH7`=#:+
M5"0,C8.6H?__Z.SB__^)Q87`#X0"`0``BT8,@^P,BS#_-^CSL___@\0,5590
MZ+BS__^#Q!"#[`S_-^C;L___@\0,C9/MHO__:@%24.C9LO__B<98_S?HO[/_
M_X/$#(V3`J/__U)64.A^L___6O\WZ*:S__^+5"0<QD!I`(V#C:'__^ASXO__
M@\00B<:)@WP1``"%P'1$@^P(:,`!``!6Z&:R__^#Q!"-4`&#^@%V"8/X$0^%
MJ@```(M$)!QE,P44````#X64````@\0L6UY?7<.-M"8`````9I"#[`S_LW01
M``#HLO#__X/$$(G&B8-\$0``A<!UGX/L#(V#T*/__U#HY+3__XUT)@"`>`$`
M#X1,_?__Z4+]__^0BX-T$0``@^P,BRB+1@R+,/\WZ.FR__^)ZHGPZ(#G__^#
MQ!#I\_[__X/L#/\WZ,ZR__]97590Z#6T__^#Q!#I?O[__^@X`0``4(N#=!$`
M`%;_,(V#]*/__U#H<K3__V:05^AP````@<?Z;P``5E.+7"00@^P,4^C%Z___
M@\00#[80B<:$TG09C;0F`````&:0@\`!@/HO#[80#T3PA-)U\.A+[O__A=MT
M'X7`=!N`.P!T%KD$````C;^9HO__\Z8/E\`<`(3`=`1;7E_#B=A;7E_INN3_
M_XL\),-FD&:09I!3Z$JW__^!PWIO``"#[`C_LS0!``#_="0<_W0D'/]T)!SH
M>K'__X/$&%O#9I!FD)!55U93Z!>W__^!PT=O``"#[`R+;"0HC;/<_O__Z%^P
M__^-@]C^__\IQL'^`H7V="4Q_XVV`````(/L!%7_="0L_W0D+/^4N]C^__^#
MQP&#Q!`Y_G7C@\0,6UY?7<.-=@#SPV:09I!FD&:09I!FD&:04^BJMO__@</:
M;@``@^P(Z.RR__]3@^P(Z).V__^!P\-N``"#Q`A;PP``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````#`````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,
M;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O
M<')O8R\E:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"
M`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?
M4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/
M0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)
M0E)!4EE?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).
M04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S
M)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L
M`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-#<`+64`+2T```!?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````!P97)L>'-I+F,````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI
M('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I
M;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS
M=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR
M;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-
M4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%
M(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD[
M"G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P
M-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@
M+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C
M;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E
M<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'
M24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T
M7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D
M<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D
M<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED
M>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E
M="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E
M96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E
M860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@
M(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I
M9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X
M(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@
M,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*
M)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR
M96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K
M*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B
M=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68[
M"F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@
M)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@
M)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M
M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D
M97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@
M)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD
M(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")3
M2$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]
M("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R
M968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E
M("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E
M86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO
M9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.
M0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@
M*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI
M('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E
M:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA
M;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA
M;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I
M92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR
M971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO
M="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S
M7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R
M7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE
M*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%
M55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL
M97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'
M5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T
M7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@
M("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI
M.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF
M="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]
M"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN
M8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`
M861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U
M<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R
M9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L
M<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H
M)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@
M)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N
M("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO
M9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D
M,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE
M>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D
M;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J
M,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@
M9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]
M"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R
M(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E
M9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X[
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V
M86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@
M)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U
M8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N
M("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@
M)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE
M9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U
M;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D[
M"FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF
M;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I
M.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE
M;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@
M)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O
M6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F
M:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@
M(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E
M;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B
M*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R
M("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE
M*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^
M861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE
M("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?
M;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[
M4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN
M="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X
M="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@
M)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]
M?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]
M>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL
M93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M
M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC
M;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?
M;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B
M*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE
M(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2
M.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T
M97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E
M<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E
M(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER
M92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H
M"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@
M=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]
M("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<
M5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G
M;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE
M;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D
M8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P
M<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@
M*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H
M+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M
M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO
M<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO
M9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T
M96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G
M;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*
M?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2![
M"FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF
M("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D
M*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R
M;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W
M9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID
M96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0
M($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,
M7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@
M*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D
M=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR
M971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B
M0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN
M8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@
M;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L
M:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E
M;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N
M<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R
M7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T
M("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N
M;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D
M,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF
M("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,[
M\````!T```#T8/__#`$``,1D__\P`0``U&3__S`-``!D:/__1`$``!21__^(
M`0``Y)'__P`"``!TDO__.`(``,24__^X`@``1);__W`#``#4EO__P`,``,27
M__]<!```!)C__XP$``!DF/__V`0``"29__]H!0``-)G__WP%``!$F___9`8`
M`'2;__]X!@``5)S__^@&```DGO__(`<``*2>__]$!P``Y)[__W@'``"TG___
MY`<``!2L__]T"P``E*___^@,```*L/__>`T``!2P__^,#0``1+#__[@-``"D
ML/__!`X``+2P__\8#@``%``````````!>E(``7P(`1L,!`2(`0``(````!P`
M``#@7___T`,````."$8.#$H/"W0$>``_&CLJ,B0B$````$````",8___$```
M``````!`````5````!AG__^F*````$$."(4"1`X,AP-!#A"&!$$.%(,%1@Z@
M!@./*`H.%$'##A!!Q@X,0<<."$'%#@1!"P```'0```"8````A(___\0`````
M00X(A0)!#@R'`T$.$(8$00X4@P5.#C`"00XT00XX1`X\00Y`2`XP5PH.%$/#
M#A!!Q@X,0<<."$'%#@1""VX*#A1#PPX00<8.#$''#@A!Q0X$1`M##A1#PPX0
M0\8.#$''#@A!Q0X$`#0````0`0``W(___X(`````3`X(AP)!#@R&`T,.$(,$
M0PX@`F8*#A!!PPX,0<8."$''#@1!"P``?````$@!```TD/__0@(```!!#@B%
M`D,.#(<#00X0A@1##A2#!4X.3%<.4$@.0%H.3$,.4$@.0`)-#DQ-#E!(#D`"
M<0H.%$'##A!!Q@X,0<<."$'%#@1'"P)<#DQ!#E!2#D!+#D1(#DA)#DQ%#E!0
M#D!C#DA!#DQ!#E!0#D````"T````R`$```22__]^`0```$$."(4"0PX,AP-!
M#A"&!$$.%(,%40Z@`6T*#A1!PPX00<8.#$''#@A!Q0X$2`M##JP!00ZP`4P.
MH`%;#JP!1`ZP`4@.H`%^#JP!00ZP`68.K`%'#J@!10ZL`4$.L`%!#K0!0@ZX
M`4(.O`%!#L`!2`ZD`44.J`%!#JP!0@ZP`4@.H`%8#JP!00ZP`4@.H`%##JP!
M00ZP`4@.H`%/#JP!1`ZP`5`.H`$`3````(`"``#,DO__@@````!!#@B&`D,.
M#(,#3@Z$`5$.B`%!#HP!0@Z0`4@.@`%A#H@!0@Z,`4$.D`%(#H`!8`H.#$'#
M#@A!Q@X$00L```"8````T`(```R3___A`````$$."(4"00X,AP-##A"&!$$.
M%(,%40[$(%@.R"!+#LP@00[0($@.P"!A#L0@00[(($(.S"!!#M`@2`[`($L.
MS"!!#M`@1@[4($$.V"!!#MP@00[@($@.P"!6"@X40<,.$$'&#@Q!QPX(0<4.
M!$D+4P[,($$.T"!(#L0@1`[(($$.S"!!#M`@2`[`(``L````;`,``&"3__\[
M`````$$."(,"3@X<2`X@3`XD3`XH00XL00XP2`X(0<,.!`!(````G`,``'"3
M__]3`````$$."(8"00X,@P-.#AQ(#B!.#AQ"#B!&#AQ'#AA"#AQ!#B!!#B1'
M#BA'#BQ!#C!(#@Q!PPX(0<8.!```C````.@#``"$D___M@````!!#@B%`D$.
M#(<#00X0A@1!#A2#!5$.L$!7#KA`1PZ\0$$.P$!'#L1`10[(0$(.S$!%#M!`
M2`ZT0$4.N$!(#KQ`00[`0$H.L$!'#KQ`1@[`0$@.L$!)#K1`00ZX0$$.O$!!
M#L!`3`ZP0%@*#A1!PPX00<8.#$''#@A!Q0X$00L`$````'@$``"TD___!0``
M``````#D````C`0``+"3__\%`@```$$."(4"00X,AP-!#A"&!$$.%(,%40ZP
M(7D.N"%"#KPA0P[`(4@.L"%Q"@X40<,.$$'&#@Q!QPX(0<4.!$@+0PZ\(40.
MP"%&#KPA00ZX(4\.O"%!#L`A2`ZP(68.N"%!#KPA00[`(4@.L"%+#KPA00[`
M(4@.L"%R#K0A2@ZX(4$.O"%'#L`A00[$(44.R"%"#LPA2`[0(4@.M"%$#K@A
M00Z\(4(.P"%(#K`A5PZX(40.O"%"#L`A2`ZP(0)!#K@A0@Z\(4$.P"%(#K`A
M5`Z\(4$.P"%(#K`A$````'0%``#8E/__*0````````!L````B`4``/24___8
M`````$$."(8"00X,@P-.#A!8#AQ!#B!(#A!W#AQ'#B!(#A!#"@X,0<,."$'&
M#@1$"V4.%$$.&$$.'$<.($@.$$4*#@Q!PPX(0<8.!$,+0PX<1PX@2`X00PX,
M0<,."$'&#@0`-````/@%``!DE?__T`$```!!#@B'`D$.#(8#00X0@P1.#D`#
M8`$*#A!!PPX,0<8."$''#@1$"P`@````,`8``/R6__]V`````$$."(,"3@X@
M9PH."$'##@1)"P`P````5`8``%B7__\W`````$$."(,"3@X02`X<00X@2`X0
M20H."$'##@1&"T,."$/##@0`:````(@&``!DE___Q@````!!#@B%`D$.#(<#
M00X0A@1!#A2#!4X.,`)'"@X40<,.$$'&#@Q!QPX(0<4.!$,+0PXX00X\00Y`
M2`XP1PX\00Y`7@XT20XX00X\1PY`00Y$0@Y(0@Y,00Y02`XPC`,``/0&``#(
ME___5PP```!,#@B%`D$.#(<#00X0A@1!#A2#!48.H(,"`NH.K(,"00ZP@P)>
M#J"#`FD.K(,"1`ZP@P)!#K2#`D(.N(,"0@Z\@P)!#L"#`D\.H(,"`DL.K(,"
M00ZP@P),#J"#`@)_#JR#`D@.L(,"30ZT@P)/#KB#`DL.O(,"1P[`@P)!#L2#
M`D(.R(,"0@[,@P)%#M"#`D@.J(,"10ZL@P)$#K"#`D@.H(,"6`ZD@P)!#JB#
M`D0.K(,"0@ZP@P),#J"#`DT.K(,"1`ZP@P)&#K2#`DL.N(,"2`Z\@P)"#L"#
M`D@.H(,"9@H.%$'##A!!Q@X,0<<."$'%#@1'"VD.K(,"00ZP@P),#J"#`@)@
M#JR#`D$.L(,"7PZ@@P)+#JR#`D$.L(,"2@ZL@P)!#JB#`D$.K(,"1@ZP@P),
M#J"#`DL.K(,"10ZP@P),#J"#`@)0#JB#`D(.K(,"1`ZP@P)0#J"#`FL.I(,"
M00ZH@P)0#JR#`D0.L(,"00ZT@P)"#KB#`D(.O(,"1`[`@P)(#J"#`FH.K(,"
M1`ZP@P)!#K2#`D$.N(,"1`Z\@P)$#L"#`D$.Q(,"0@[(@P)"#LR#`D$.T(,"
M3`Z@@P)##JB#`D4.K(,"00ZP@P),#J"#`D@.K(,"1`ZP@P)G#J"#`GP.K(,"
M00ZP@P),#J"#`DX*#JB#`D$.K(,"1`ZP@P)&#K2#`ED+0PZL@P)!#K"#`F`.
MH(,"2`ZL@P)"#K"#`E@.H(,"6PZD@P)"#JB#`D(.K(,"10ZP@P).#J2#`D(.
MJ(,"3`ZL@P)!#K"#`D@.H(,"6@ZD@P)"#JB#`D(.K(,"1`ZP@P("L0Z@@P)A
M#J2#`D4.J(,"1`ZL@P)$#K"#`DP.H(,"`I\.I(,"00ZH@P)$#JR#`D$.L(,"
M7`Z@@P("_PZD@P)!#JB#`D$.K(,"1`ZP@P)3#J"#`E<.K(,"1`ZP@P)^#J"#
M`@+K#JR#`D0.L(,"00ZT@P)"#KB#`D(.O(,"00[`@P)/#J"#`ED.I(,"2@ZH
M@P)$#JR#`D0.L(,"00ZT@P)"#KB#`D(.O(,"1`[`@P)(#J"#`E<.K(,"00ZP
M@P)2#J"#`@+J#J2#`D(.J(,"0@ZL@P)%#K"#`DX.I(,"0@ZH@P)%#JR#`D$.
ML(,"3`ZT@P)'#KB#`D0.O(,"1`[`@P)!#L2#`D(.R(,"0@[,@P)$#M"#`D@.
MH(,"<`$``(0*``"8H/__?@,```!!#@B%`D$.#(<#00X0A@1!#A2#!4X.3%0.
M4$8.3$(.4&8.0%4.3$(.4$T.5$(.6$$.7$$.8$@.0'(.2$0.3$D.4$P.0%H.
M3$$.4$<.5$$.6$0.7$$.8$@.0%X.3$$.4$<.5$(.6$4.7$$.8$H.0'8.3$0.
M4$8.3$$.2$$.3$$.4$@.0$T.3$$.4$T.5$(.6$$.7$$.8$@.0$P.3$0.4$@.
M1$<.2$$.3$$.4$L.0$\.3$(.4$T.5$(.6$$.7$$.8$@.0&4.3$0.4$@.1$$.
M2$$.3$$.4$@.0$,.3$(.4$@.1$@.2$$.3$$.4$@.3$(.4$@.1$<.2$$.3$$.
M4$8.3$(.4%L.0$\.2$4.3$$.4$@.0&4*#A1!PPX00<8.#$''#@A!Q0X$2@M#
M"@Y,1@Y02`Y`3PY,1PY020M9#DQ)#E!1#D!(#DQ"#E!&#DQ!#DA!#DQ!#E!(
M#D!+#D1'#DA"#DQ'#E``1````/@+``"DHO__=@````!!#@B'`DP.#(8#00X0
M@P1'#AQ!#B!(#A`"2PK##@Q!Q@X(0<<.!$$+0\,.#$'&#@A!QPX$````1```
M`$`,``"<5___3`(```!$#`$`1Q`%`G4`0Q`'`G5\1!`&`G5X$`,"=71,#P-U
M<`8#>@$*P0P!`$'#0<9!QT'%0PP$!$$+$````(@,``"*HO__!``````````H
M````G`P``("B__\K`````$$."(,"3@X01@X41`X81`X<1`X@2`X(0<,.!$@`
M``#(#```A*+__UT`````00X(A0)!#@R'`T$.$(8$00X4@P5.#B!I#B1!#BA$
M#BQ$#C!-#B!'#A1!PPX00<8.#$''#@A!Q0X$```0````%`T``)BB__\"````
M`````!@````H#0``E*+__Q0`````00X(@P).#A``````````````````````
M`````````````````````````````````````````````````````````)`G
M``!`)P```0````$````!````RP$```$```#6`0```0```.`!```!````+P(`
M``$```"*`P``#``````@```-````!'```!D```"HW0``&P````0````:````
MK-T``!P````$````]?[_;^P!```%````+`D```8```#,`@``"@```/P$```+
M````$````!4``````````P```-#>```"````X`$``!0````1````%P```!P0
M```1````E`\``!(```"(````$P````@````>````"````/O__V\!```(_O__
M;_0.``#___]O`@```/#__V\H#@``^O__;P4`````````````````````````
M````````````````````````````````L-T`````````````1B```%8@``!F
M(```=B```(8@``"6(```IB```+8@``#&(```UB```.8@``#V(```!B$``!8A
M```F(0``-B$``$8A``!6(0``9B$``'8A``"&(0``EB$``*8A``"V(0``QB$`
M`-8A``#F(0``]B$```8B```6(@``)B(``#8B``!&(@``5B(``&8B``!V(@``
MAB(``)8B``"F(@``MB(``,8B``#6(@``YB(``/8B```&(P``%B,``"8C```V
M(P``1B,``%8C``!F(P``=B,``(8C``"6(P``IB,``+8C``#&(P``UB,``.8C
M``#V(P``````````````````````````````````````````````````````
M````````````$"0````````$X```_____PB#``!'0T,Z("A$96)I86X@."XR
M+C`M.2D@."XR+C``1T-#.B`H1&5B:6%N(#<N,RXP+3(Y*2`W+C,N,```+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M
M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N8G-S`"YC
M;VUM96YT````````````````````````````````````````````````````
M```````+`````0````(```"4`0``E`$``!,```````````````$`````````
M$P````<````"````J`$``*@!```@```````````````$`````````"$````'
M`````@```,@!``#(`0``)```````````````!``````````T````]O__;P(`
M``#L`0``[`$``.`````%``````````0````$````/@````L````"````S`(`
M`,P"``!@!@``!@````$````$````$````$8````#`````@```"P)```L"0``
M_`0``````````````0````````!.````____;P(````H#@``*`X``,P````%
M``````````(````"````6P```/[__V\"````]`X``/0.``"@````!@````(`
M```$`````````&H````)`````@```)0/``"4#P``B`````4`````````!```
M``@```!S````"0```$(````<$```'!```.`!```%````%@````0````(````
M?`````$````&`````"`````@```C```````````````$`````````'<````!
M````!@```#`@```P(```T`,`````````````$`````0```""`````0````8`
M````)````"0``!````````````````@````(````BP````$````&````$"0`
M`!`D``#T2P`````````````0`````````)$````!````!@````1P```$<```
M%```````````````!`````````"7`````0````(`````@````(```#P_````
M``````````0`````````GP````$````"````/+\``#R_``#T````````````
M```$`````````*T````!`````@```##````PP```1`T`````````````!```
M``````"W````#@````,```"HW0``J,T```0```````````````0````$````
MPP````\````#````K-T``*S-```$```````````````$````!````,\````&
M`````P```+#=``"PS0``(`$```8`````````!`````@```"&`````0````,`
M``#0W@``T,X``#`!``````````````0````$````V`````$````#`````.``
M``#0```0```````````````$`````````-X````(`````P```"#@```0T```
M-!``````````````(`````````#C`````0```#``````````$-```#D`````
M``````````$````!`````0````,``````````````$G0``#L````````````
*```!````````````
